from odoo import models
from odoo.addons.saas_worker.compat import request


class Http(models.AbstractModel):
    _inherit = 'ir.http'

    @classmethod
    def get_utm_domain_cookies(cls):
        """ Force cookies for UTM to be shared between *.odoo.com. Else, we cannot have
            informations save in www.odoo.com from accounts.odoo.com
        """
        return "." + ".".join(request.httprequest.host.rsplit(".", 2)[1:])

    def binary_content(self, **kwargs):
        env = self.env
        if env:
            obj = None
            if kwargs.get('xmlid'):
                obj = env.ref(kwargs['xmlid'], False).sudo()
            elif kwargs.get('id') and kwargs.get('model') in env.registry:
                obj = env[kwargs['model']].browse(int(kwargs['id'])).sudo()
            # we set the env as a sudo to allow the display of the product images that are Odoo App or Odoo User product
            # we need this because of the pricing page, adding product to the cart that are in website_published=False.
            if obj and obj._name == "product.product" and (obj.is_odoo_app or obj.is_odoo_user):
                return super(Http, self.sudo()).binary_content(**kwargs)
        return super(Http, self).binary_content(**kwargs)

    @classmethod
    def _get_translation_frontend_modules_name(cls):
        mods = super(Http, cls)._get_translation_frontend_modules_name()
        return mods + ['openerp_enterprise']
